@@ -1114,7 +1114,7 @@ class WordToken(caching.base.CachingMixin,models.Model):
             if 'S' in form['lexical_scale'] and 'SpeakerSPhoneProb' not in outline:
                 qs = WordToken.objects.filter(Dialog__Speaker= self.Dialog.Speaker).filter(WordType=self.WordType).order_by('Dialog')
                 for q in qs:
-                    if 'SpeakerSPhoneProb' in q.Output:
+                    if q.Output is not None and 'SpeakerSPhoneProb' in q.Output:
                         outline['SpeakerSPhoneProb'],outline['SpeakerBiPhoneProb'] = q.Output['SpeakerSPhoneProb'],q.Output['SpeakerBiPhoneProb']
                         break
                 else:
@@ -1122,7 +1122,7 @@ class WordToken(caching.base.CachingMixin,models.Model):
             if 'A' in form['lexical_scale'] and 'AgeSPhoneProb' not in outline:
                 qs = WordToken.objects.filter(Dialog__Speaker__Age= self.Dialog.Speaker.Age).filter(WordType=self.WordType).order_by('Dialog')
                 for q in qs:
-                    if 'AgeSPhoneProb' in q.Output:
+                    if q.Output is not None and 'AgeSPhoneProb' in q.Output:
                         outline['AgeSPhoneProb'],outline['AgeBiPhoneProb'] = q.Output['AgeSPhoneProb'],q.Output['AgeBiPhoneProb']
                         break
                 else:
@@ -1130,7 +1130,7 @@ class WordToken(caching.base.CachingMixin,models.Model):
             if 'G' in form['lexical_scale'] and 'GenderSPhoneProb' not in outline:
                 qs = WordToken.objects.filter(Dialog__Speaker__Gender= self.Dialog.Speaker.Gender).filter(WordType=self.WordType).order_by('Dialog')
                 for q in qs:
-                    if 'GenderSPhoneProb' in q.Output:
+                    if q.Output is not None and 'GenderSPhoneProb' in q.Output:
                         outline['GenderSPhoneProb'],outline['GenderBiPhoneProb'] = q.Output['GenderSPhoneProb'],q.Output['GenderBiPhoneProb']
                         break
                 else:
